import 'package:flutter_test/flutter_test.dart';

import 'package:numerology/numerology.dart';

void main() {
  final _instance = NumerologyCalculator();
  final day08011998 = DateTime(1998, 1, 8); // Ruling: 9
  final day22121999 = DateTime(1999, 12, 22); //  Ruling: 8
  final day03071551 = DateTime(1551, 7, 3); // Ruling: 22
  final universalYear5 = DateTime(2021); // 5
  final fullNameTranPhatHung = "Tran Phat Hung"; // '2915 7812 8357'
  final fullNameArthurConanDoyle = "Arthur Conan Doyle"; // '192839 36515 46735'

  test("Test dd-MM-yyyt fomat", () {
    expect(_instance.toDdMnYyyy(day08011998), "08-01-1998");
    expect(_instance.toDdMnYyyy(day22121999), "22-12-1999");
  });

  test("Test ddMMyyyy fomat", () {
    expect(_instance.toDmy(day08011998), "08011998");
    expect(_instance.toDmy(day22121999), "22121999");
  });

  test("Test Ruling number", () {
    expect(_instance.rulingNumber(day08011998), 9);
    expect(_instance.rulingNumber(day22121999), 8);
    expect(_instance.rulingNumber(day03071551), 22);
  });

  test("Test Universal Year Number", () {
    expect(_instance.universalYearNumber(dateTime: day22121999), 1);
    expect(_instance.universalYearNumber(dateTime: day08011998), 9);
    expect(_instance.universalYearNumber(dateTime: day03071551), 3);
  });

  test("Test Personal Year", () {
    expect(_instance.personalYear(day08011998, currentYear: universalYear5), 5);
    expect(_instance.personalYear(day22121999, currentYear: universalYear5), 3);
    expect(_instance.personalYear(day03071551, currentYear: universalYear5), 6);
  });

  test("Test Personal Month", () {
    expect(
        _instance.personalMonth(
          day08011998.add(Duration(days: 90)), // 08-04-1998
          day08011998,
        ),
        4); // ((1998) + 8 + 1) + 4 = (9 + 8 + 1) + 4 = 9 + 4 = 4
    expect(
        _instance.personalMonth(
          day22121999.add(Duration(days: 10)), // 1-1-2000
          day22121999,
        ),
        1); // ((2000) + 12 + 22) + 1 = (2 + 12 + 22) + 1 = 9 + 1 = 1
    expect(
        _instance.personalMonth(
          day08011998, // 08-01-1998
          day03071551,
        ),
        2); // ((1998) + 7 + 3) + 1 = (9 + 7 + 3) + 1 = 1 + 1 = 2
  });

  test("Test Personal Day", () {
    expect(
        _instance.personalDay(
          day08011998.add(Duration(days: 90)), // 08-04-1998
          day08011998,
        ),
        3); // Personal month: 4, day = 8 -> Personal day = 4 + 8 = 12 -> 1 + 2 = 3
    expect(
        _instance.personalDay(
          day22121999.add(Duration(days: 10)), // 1-1-2000
          day22121999,
        ),
        2); // Personal month: 1, day = 1 -> Personal day = 1 + 1 = 2
    expect(
        _instance.personalDay(
          day08011998, // 08-01-1998
          day03071551,
        ),
        1); // Personal month: 2, day = 8 -> Personal day = 2 + 8 = 10 -> 1 + 0 = 1
  });

  test("Test lifePathNumber", () {
    expect(_instance.lifePathNumber(day08011998),
        9); // 8 + 1 + (1998) = 8 + 1 + 9 = 18 -> 1 + 8 = 9
    expect(_instance.lifePathNumber(day22121999),
        8); // 22 + 3 + (1999) = 22 + 3 + 1 = 26 -> 2 + 6 = 8
    expect(_instance.lifePathNumber(day03071551),
        4); // 3 + 7 + (1551) = 3 + 7 + 3 = 13 -> 1 + 3 = 4
  });

  test("Test Attitude Number", () {
    expect(
      _instance.attitudeNumber(day03071551),
      1,
    ); // 3 + 7 = 10 -> 1 + 0 = 1
    expect(
      _instance.attitudeNumber(day22121999),
      7,
    ); // 22 + 12 = 34 -> 3 + 4 = 7
    expect(_instance.attitudeNumber(day08011998), 9); // 8 + 1 = 9
  });

  test("Tets sumReduceNumText", () {
    expect(_instance.sumReduceNumText('12345'), 6);
    expect(_instance.sumReduceNumText('99999'), 9);
    expect(_instance.sumReduceNumText('78901'), 7);
  });

  test("Test destinyNumber", () {
    expect(_instance.destinyNumber(day22121999), 8); // 4 + 3 + 28 = 35 = 8
    expect(_instance.destinyNumber(day08011998), 9); // 8 + 1 + 27 = 36 = 9
    expect(_instance.destinyNumber(day03071551), 4); // 3 + 7 + 12 = 22 = 4
  });

  test("Tets nameInDigit", () {
    expect(_instance.nameInDigit(fullNameTranPhatHung), "2915 7812 8357");
    expect(
      _instance.nameInDigit(fullNameArthurConanDoyle),
      "192839 36515 46735",
    );
  });

  test("Test expressionNumber", () {
    expect(
      _instance.expressionNumber(fullNameTranPhatHung),
      22,
    ); //"2915 7812 8357" = 8 + 9 + 5 = 22 (master number)
    expect(
      _instance.expressionNumber(fullNameArthurConanDoyle),
      5,
    ); //"192839 36515 46735" = 5 + 2 + 7 = 14 = 5
  });

  test("Test consonantNameDigit", () {
    expect(_instance.consonantNameDigit(fullNameTranPhatHung), "295 782 857");
    expect(
      _instance.consonantNameDigit(fullNameArthurConanDoyle),
      "9289 355 473",
    );
  });

  test("Test personalityNumber", () {
    expect(
      _instance.personalityNumnber(fullNameTranPhatHung),
      8,
    ); // Only consotants "295 782 857" = 7 + 8 + 2 = 8
    expect(
      _instance.personalityNumnber(fullNameArthurConanDoyle),
      1,
    ); // Only consotants "9289 355 473" = 1 + 4 + 5 = 1
  });

  test("Test vowelNameDigit", () {
    expect(_instance.vowelsNameDigit(fullNameTranPhatHung), "1 1 3");
    expect(
      _instance.vowelsNameDigit(fullNameArthurConanDoyle),
      "13 61 65",
    );
  });

  test("Test soulUrgeNumber", () {
    expect(
      _instance.soulUrgeNumber(fullNameTranPhatHung),
      5,
    ); // Only consotants "1 1 3" = 5
    expect(
      _instance.soulUrgeNumber(fullNameArthurConanDoyle),
      22,
    ); // Only consotants "13 61 65" = 4 + 7 + 11 = 22 (master number)
  });
}
